@@ -57,10 +57,10 @@ GJS_DEFINE_PRIV_FROM_JS(Ns, gjs_ns_class)
  */
 static JSBool
 ns_new_resolve(JSContext *context,
-               JSObject **obj,
-               jsid      *id,
-               unsigned   flags,
-               JSObject **objp)
+               JS::HandleObject obj,
+               JS::HandleId id,
+               unsigned flags,
+               JS::MutableHandleObject objp)
 {
     Ns *priv;
     char *name;
@@ -68,9 +68,7 @@ ns_new_resolve(JSContext *context,
     GIBaseInfo *info;
     JSBool ret = JS_FALSE;
 
-    *objp = NULL;
-
-    if (!gjs_get_string_id(context, *id, &name))
+    if (!gjs_get_string_id(context, id, &name))
         return JS_TRUE; /* not resolved, but no error */
 
     /* let Object.prototype resolve these */
@@ -80,7 +78,7 @@ ns_new_resolve(JSContext *context,
         goto out;
     }
 
-    priv = priv_from_js(context, *obj);
+    priv = priv_from_js(context, obj);
     gjs_debug_jsprop(GJS_DEBUG_GNAMESPACE, "Resolve prop '%s' hook obj %p priv %p", name, *obj, priv);
 
     if (priv == NULL) {
@@ -106,9 +104,9 @@ ns_new_resolve(JSContext *context,
               g_base_info_get_name(info),
               g_base_info_get_namespace(info));
 
-    if (gjs_define_info(context, *obj, info)) {
+    if (gjs_define_info(context, obj, info)) {
         g_base_info_unref(info);
-        *objp = *obj; /* we defined the property in this object */
+        objp.set(obj); /* we defined the property in this object */
         ret = JS_TRUE;
     } else {
         gjs_debug(GJS_DEBUG_GNAMESPACE,
